@@ -1,7 +1,7 @@
 <?php
 
 require_once 'Auth/OpenID/Server.php';
-require_once 'server_ext.php';
+require_once dirname(__FILE__) . '/server_ext.php';
 
 add_filter( 'xrds_simple', 'openid_provider_xrds_simple');
 add_action( 'wp_head', 'openid_provider_link_tags');
@@ -44,7 +44,8 @@ function openid_provider_xrds_simple($xrds) {
 	
 	if (!$user && get_option('openid_blog_owner')) {
 		$url_parts = parse_url(get_option('home'));
-		$path = trailingslashit($url_parts['path']);
+		$path = array_key_exists('path', $url_parts) ? $url_parts['path'] : '';
+		$path = trailingslashit($path);
 
 		$script = preg_replace('/index.php$/', '', $_SERVER['SCRIPT_NAME']);
 		$script = trailingslashit($script);
@@ -54,7 +55,7 @@ function openid_provider_xrds_simple($xrds) {
 		}
 
 		if (!defined('OPENID_DISALLOW_OWNER') || !OPENID_DISALLOW_OWNER) {
-			$user = get_userdatabylogin(get_option('openid_blog_owner'));
+			$user = get_user_by('login', get_option('openid_blog_owner'));
 		}
 	}
 
@@ -63,8 +64,8 @@ function openid_provider_xrds_simple($xrds) {
 		$user_object = new WP_User($user->ID);
 		if (!$user_object->has_cap('use_openid_provider')) return $xrds;
 
-		if (get_usermeta($user->ID, 'openid_delegate')) {
-			$services = get_usermeta($user->ID, 'openid_delegate_services');
+		if (get_user_meta($user->ID, 'openid_delegate', true)) {
+			$services = get_user_meta($user->ID, 'openid_delegate_services', true);
 		} else {
 			$services = array();
 
@@ -120,17 +121,19 @@ function openid_provider_xrds_simple($xrds) {
 function openid_server_requested_user() {
 	global $wp_rewrite;
 
-	if ($_REQUEST['author']) {
+	if (array_key_exists('author', $_REQUEST) && $_REQUEST['author']) {
 		if (is_numeric($_REQUEST['author'])) {
-			return get_userdata($_REQUEST['author']);
+			return get_user_by('id', $_REQUEST['author']);
 		} else {
-			return get_userdatabylogin($_REQUEST['author']);
+			return get_user_by('login', $_REQUEST['author']);
 		}
 	} else {
 		$regex = preg_replace('/%author%/', '(.+)', $wp_rewrite->get_author_permastruct());
 		preg_match('|'.$regex.'|', $_SERVER['REQUEST_URI'], $matches);
-		$username = sanitize_user($matches[1], true);
-		return get_userdatabylogin($username);
+		if ($matches) {
+			$username = sanitize_user($matches[1], true);
+			return get_user_by('login', $username);
+		}
 	}
 }
 
@@ -214,7 +217,7 @@ function openid_server_auth_request($request) {
 	}
 
 	// if using id select but user is delegating, display error to user (unless checkid_immediate)
-	if ($id_select && get_usermeta($user->ID, 'openid_delegate')) {
+	if ($id_select && get_user_meta($user->ID, 'openid_delegate', true)) {
 		if ($request->mode != 'checkid_immediate') {
 			if ($_REQUEST['action'] == 'cancel') {
 				check_admin_referer('openid-server_cancel');
@@ -248,11 +251,11 @@ function openid_server_auth_request($request) {
 	}
 
 	// if user trusts site, we're done
-	$trusted_sites = get_usermeta($user->ID, 'openid_trusted_sites');
+	$trusted_sites = get_user_meta($user->ID, 'openid_trusted_sites', true);
 	$site_hash = md5($request->trust_root);
 	if (is_array($trusted_sites) && array_key_exists($site_hash, $trusted_sites)) {
 		$trusted_sites[$site_hash]['last_login'] = time();
-		update_usermeta($user->ID, 'openid_trusted_sites', $trusted_sites);
+		update_user_meta($user->ID, 'openid_trusted_sites', $trusted_sites);
 
 		if ($id_select) { 
 			return $request->answer(true, null, $author_url);
@@ -340,7 +343,7 @@ function openid_provider_link_tags() {
 
 	if (is_front_page()) {
 		if (!defined('OPENID_DISALLOW_OWNER') || !OPENID_DISALLOW_OWNER) {
-			$user = get_userdatabylogin(get_option('openid_blog_owner'));
+			$user = get_user_by('login', get_option('openid_blog_owner'));
 		}
 	} else if (is_author()) {
 		global $wp_query;
@@ -352,8 +355,8 @@ function openid_provider_link_tags() {
 		$user_object = new WP_User($user->ID);
 		if (!$user_object->has_cap('use_openid_provider')) return;
 
-		if (get_usermeta($user->ID, 'openid_delegate')) {
-			$services = get_usermeta($user->ID, 'openid_delegate_services');
+		if (get_user_meta($user->ID, 'openid_delegate', true)) {
+			$services = get_user_meta($user->ID, 'openid_delegate_services', true);
 			$openid_1 = false;
 			$openid_2 = false;
 
@@ -422,11 +425,11 @@ function openid_server_user_trust($request) {
 				$site = array( 'url' => $request->trust_root, 'last_login' => time());
 				$site = apply_filters('openid_server_store_trusted_site', $site);
 
-				$trusted_sites = get_usermeta($user->ID, 'openid_trusted_sites');
+				$trusted_sites = get_user_meta($user->ID, 'openid_trusted_sites', true);
 				$site_hash = md5($request->trust_root);
 				$trusted_sites[$site_hash] = $site;
 
-				update_usermeta($user->ID, 'openid_trusted_sites', $trusted_sites);
+				update_user_meta($user->ID, 'openid_trusted_sites', $trusted_sites);
 			}
 		}
 
@@ -510,7 +513,7 @@ function openid_server_user_trust($request) {
  * @return bool true if successful
  */
 function openid_server_get_delegation_info($userid, $url = null) {
-	if (empty($url)) $url = get_usermeta($userid, 'openid_delegate');
+	if (empty($url)) $url = get_user_meta($userid, 'openid_delegate', true);
 	if (empty($url)) return false;
 
 	$fetcher = Auth_Yadis_Yadis::getHTTPFetcher();
